@@ -1,7 +1,7 @@
-from paypalrestsdk.resource import Find, Create, Delete
+from paypalrestsdk.resource import Find, Create, Delete, Replace
 
 
-class CreditCard(Find, Create, Delete):
+class CreditCard(Find, Create, Delete, Replace):
     """Use vault api to avoid having to store sensitive information
     such as credit card related details on your server. API docs at
     https://developer.paypal.com/docs/api/#vault
